# This file was auto-generated by Fern from our API Definition.

import typing
from ...types.dynamic_manager import DynamicManager
from ...types.round_robin_manager import RoundRobinManager
from ...types.sleeptime_manager import SleeptimeManager
from ...types.supervisor_manager import SupervisorManager

GroupUpdateManagerConfig = typing.Union[DynamicManager, RoundRobinManager, SleeptimeManager, SupervisorManager]



# This file was auto-generated by Fern from our API Definition.

import typing

ToolType = typing.Union[
    typing.Literal[
        "custom",
        "letta_core",
        "letta_memory_core",
        "letta_multi_agent_core",
        "letta_sleeptime_core",
        "external_composio",
        "external_langchain",
        "external_mcp",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_request_search_item_zero import AgentsSearchRequestSearchItemZero
from .agents_search_request_search_item_one import AgentsSearchRequestSearchItemOne
from .agents_search_request_search_item_two import AgentsSearchRequestSearchItemTwo
from .agents_search_request_search_item_operator import AgentsSearchRequestSearchItemOperator

AgentsSearchRequestSearchItem = typing.Union[
    AgentsSearchRequestSearchItemZero,
    AgentsSearchRequestSearchItemOne,
    AgentsSearchRequestSearchItemTwo,
    AgentsSearchRequestSearchItemOperator,
]



# This file was auto-generated by Fern from our API Definition.

from .letta_streaming_response import LettaStreamingResponse
from .messages_modify_request import MessagesModifyRequest
from .messages_modify_response import MessagesModifyResponse

__all__ = ["LettaStreamingResponse", "MessagesModifyRequest", "MessagesModifyResponse"]



# This file was auto-generated by Fern from our API Definition.

import typing
from .conditional_tool_rule import ConditionalToolRule
from .child_tool_rule import ChildToolRule
from .continue_tool_rule import ContinueToolRule
from .terminal_tool_rule import TerminalToolRule
from .max_count_per_step_tool_rule import MaxCountPerStepToolRule
from .init_tool_rule import InitToolRule

AgentStateToolRulesItem = typing.Union[
    ConditionalToolRule, ChildToolRule, ContinueToolRule, TerminalToolRule, MaxCountPerStepToolRule, InitToolRule
]
